# {{ cookiecutter.project_name }} Roadmap

This document lists general directions that core team is interested to see
developed in {{ cookiecutter.project_name }}

## Principal goals

<<DESCRIBE THE PRINCIPALS GOALS OF THE PROJECT?>>

- <<add your item here>>

### Codebase maintenance

<<DESCRIBE SOME SUGGESTIONS OR TASKS FOR THE CODEBASE MAINTENANCE?>>

- <<add your item here>>

### Framework support

<<Describe the frameworks supported by the project
{{ cookiecutter.project_name }} and adds relevant features>>

- <<add your item here>>

### Metrics

<<Add the types of metrics and what they are used for, if necessary>>

- <<add your item here>>

### Resolving conflicts or tasks

<<Indicates possible problems encountered in {{ cookiecutter.project_name }} and
how they can be solved by potential contributors>>

    NOTE:

    It also describes possible functions or modules that can be added to the {{ cookiecutter.project_name }} to improve its functioning. You can do this in sections. If necessary, you can place code for better understanding.

### Helper on data management

<<Indicate ways in which you want the project data management to improve>>

- <<add your item here>>

### Integrations

<<Verify compatibilities and integrations with other tecnologies>>

- <<add your item here>>

### Communications

<<Indicate how you want the project to have more impact or visibility>>

- <<add your item here>>

## Attribution

This Code of Conduct is adapted from the
[Pytorch-Ignite Roadmap](https://github.com/pytorch/ignite/wiki/Roadmap).
